@@ -86,7 +86,7 @@ static char    *rcpowerfail = RC_POWERFAIL;
 
 static char    *upstype = NULL;
 
-#if defined (__Linux__) && !defined (NEWINIT)
+#if defined (__linux__) && !defined (NEWINIT)
 /* Create a flag file for Miquel van Smoorenburg's SysV init. */
 #define PWRSTAT         "/etc/powerstatus"
 #endif
@@ -227,7 +227,7 @@ main(int argc, char **argv)
 
     parse_config(config_file);
 
-    if (upsport == NULL || upstype == NULL) {
+    if (upsport == NULL || upstype == NULL || upsstat == NULL) {
 	usage(self);
     }
     for (pups = ups; pups; pups = pups->next) {
@@ -242,7 +242,7 @@ main(int argc, char **argv)
     openlog(self, LOG_CONS | LOG_PERROR, LOG_DAEMON);
 
     if ((ups_fd = open(upsport, O_RDWR | O_NDELAY)) < 0) {
-	syslog(LOG_ERR, "%s: %s", upsport, sys_errlist[errno]);
+	syslog(LOG_ERR, "%s: %s", upsport, strerror(errno));
 	closelog();
 	exit(1);
     }
@@ -312,7 +312,10 @@ main(int argc, char **argv)
     setlevel(ups_fd, pups->cablepower.line, !pups->cablepower.inverted);
 
     /* Daemonize. */
-#if 1
+#ifdef DEBUG
+    closelog();
+    setsid();
+#else
     switch (fork()) {
       case 0:			/* Child */
 	closelog();
@@ -326,17 +329,14 @@ main(int argc, char **argv)
 	closelog();
 	exit(0);
     }
-#else
-    closelog();
-    setsid();
 #endif				/* switch(fork()) */
 
     /* Restart syslog. */
     openlog(self, LOG_CONS, LOG_DAEMON);
 
     /* Create an info file for powerfail scripts. */
-    unlink(UPSSTAT);
-    if ((stat_fd = open(UPSSTAT, O_CREAT | O_WRONLY, 0644)) >= 0) {
+    unlink(upsstat);
+    if ((stat_fd = open(upsstat, O_CREAT | O_WRONLY, 0644)) >= 0) {
 	write(stat_fd, "OK\n", 3);
 	close(stat_fd);
     }
@@ -578,11 +578,11 @@ powerfail(int failure_mode)
     alarm(3);
     if ((fd = open(INIT_FIFO, O_WRONLY)) >= 0) {
 	if (write(fd, &req, sizeof(req)) != sizeof(req)) {
-	    syslog(LOG_ERR, "cannot signal init via %s: %s", INIT_FIFO, sys_errlist[errno]);
+	    syslog(LOG_ERR, "cannot signal init via %s: %s", INIT_FIFO, strerror(errno));
 	}
 	close(fd);
     } else {
-	syslog(LOG_ERR, "cannot signal init via %s: %s", INIT_FIFO, sys_errlist[errno]);
+	syslog(LOG_ERR, "cannot signal init via %s: %s", INIT_FIFO, strerror(errno));
     }
     alarm(0);
 #else
@@ -663,7 +663,7 @@ parse_assignment(char *s)
     *eq++ = '\0';
 
 #define CFG_VARIABLE(name) \
-  if (!strcasecmp (s, #name) && name == NULL) name = strdup (eq)
+  if (!strcasecmp (s, #name)) name = strdup (eq)
 
     CFG_VARIABLE(upsport);
     else
@@ -685,7 +685,7 @@ parse_entry(char *s)
 #define FIND_START_END do { \
   while (*s && isspace (*s)) s++;		\
   if (*s == '\0')				\
-    return NULL;				\
+    return 0;					\
   for (c = s; *c && !isspace (*c); c++);	\
   if (*c != '\0')				\
     *c++ = '\0';				\
@@ -693,7 +693,7 @@ parse_entry(char *s)
 
     FIND_START_END;
     if (*s == '#')
-	return NULL;
+	return 0;
     if (parse_assignment(s) == 0) {
 	return 0;
     }
@@ -754,3 +754,9 @@ parse_config(char *fname)
     }
     fclose(f);
 }
+
+/*
+ * local variables:
+ * tab-width: 8
+ * end
+ */
